@@ -4,7 +4,7 @@ run_test <- function(model, test_formula = TRUE) {
   tf <- tidypredict_fit(model)
   pm <- parse_model(model)
   test_that("Returns the correct type and dimensions", {
-    expect_is(pm, "list")
+    expect_s3_class(pm, "list")
     expect_equal(length(pm), 2)
     expect_equal(length(pm$trees), num_trees)
     expect_equal(pm$general$model, "ranger")
@@ -12,17 +12,15 @@ run_test <- function(model, test_formula = TRUE) {
   })
   if(test_formula) {
     test_that("Returns expected case_when() dplyr formula", {
-      expect_is(tidypredict_fit(pm), "list")
+      expect_type(tidypredict_fit(pm), "list")
     })
   }
 }
 
-context("ranger")
 run_test(
   ranger::ranger(Species ~ ., data = iris, num.trees = num_trees, seed = 100, num.threads = 2)
 )
 
-context("ranger-classification")
 run_test(
   parsnip::fit(
     parsnip::set_engine(parsnip::rand_forest(trees = num_trees, mode = "classification"), "ranger", seed = 100, num.threads = 2),
@@ -31,7 +29,6 @@ run_test(
   ), test_formula = FALSE
 )
 
-context("ranger-parsnip")
 run_test(
   parsnip::fit(
     parsnip::set_engine(parsnip::rand_forest(trees = num_trees, mode = "classification"), "ranger", seed = 100, num.threads = 2),
@@ -40,7 +37,6 @@ run_test(
   )
 )
 
-context("ranger-saved")
 test_that("Model can be saved and re-loaded", {
   model <- ranger::ranger(Species ~ ., data = iris, num.trees = num_trees, seed = 100, num.threads = 2)
   mp <- tempfile(fileext = ".yml")
@@ -48,5 +44,4 @@ test_that("Model can be saved and re-loaded", {
   l <- yaml::read_yaml(mp)
   pm <- as_parsed_model(l)
   expect_silent(tidypredict_fit(pm))
-  
 })
