@@ -1,5 +1,3 @@
-context("glm")
-
 df <- mtcars
 df$cyl <- paste0("cyl", df$cyl)
 
@@ -13,8 +11,8 @@ test_that("Individual prediction difference is never above 1e-12", {
 })
 
 test_that("Intervals return a call", {
-  expect_is(
-    tidypredict_interval(glm(am ~ cyl * wt + mpg, data = mtcars, family = "gaussian")),
+  expect_equal(
+    class(tidypredict_interval(glm(am ~ cyl * wt + mpg, data = mtcars, family = "gaussian")))[1],
     "call"
   )
 })
@@ -33,12 +31,11 @@ test_that("tidypredict works when variable names are subset of other variables",
   expect_false(tidypredict_test(model4)$alert)
 })
 
-context("glm-saved")
 test_that("Model can be saved and re-loaded", {
   model <- glm(am ~ wt + disp + cyl, data = df, family = "binomial")
   mp <- tempfile(fileext = ".yml")
   yaml::write_yaml(parse_model(model), mp)
   l <- yaml::read_yaml(mp)
   pm <- as_parsed_model(l)
-  expect_silent(tidypredict_fit(pm))
+  expect_snapshot(tidypredict_fit(pm))
 })
